==> openshift-model-operatorhub-4.13.3-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface SubscriptionStatusFluent<A extends SubscriptionStatusFluent<A>> extends Fluent<A> {


    public A addToCatalogHealth(int index,SubscriptionCatalogHealth item);
    public A setToCatalogHealth(int index,SubscriptionCatalogHealth item);
    public A addToCatalogHealth(SubscriptionCatalogHealth... items);
    public A addAllToCatalogHealth(Collection<SubscriptionCatalogHealth> items);
    public A removeFromCatalogHealth(SubscriptionCatalogHealth... items);
    public A removeAllFromCatalogHealth(Collection<SubscriptionCatalogHealth> items);
    public A removeMatchingFromCatalogHealth(io.fabric8.kubernetes.api.builder.Predicate<SubscriptionCatalogHealthBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildCatalogHealth instead.
 * @return The buildable object.
 */
@Deprecated public List<SubscriptionCatalogHealth> getCatalogHealth();
    public List<SubscriptionCatalogHealth> buildCatalogHealth();
    public SubscriptionCatalogHealth buildCatalogHealth(int index);
    public SubscriptionCatalogHealth buildFirstCatalogHealth();
    public SubscriptionCatalogHealth buildLastCatalogHealth();
    public SubscriptionCatalogHealth buildMatchingCatalogHealth(io.fabric8.kubernetes.api.builder.Predicate<SubscriptionCatalogHealthBuilder> predicate);
    public Boolean hasMatchingCatalogHealth(io.fabric8.kubernetes.api.builder.Predicate<SubscriptionCatalogHealthBuilder> predicate);
    public A withCatalogHealth(List<SubscriptionCatalogHealth> catalogHealth);
    public A withCatalogHealth(SubscriptionCatalogHealth... catalogHealth);
    public Boolean hasCatalogHealth();
    public SubscriptionStatusFluent.CatalogHealthNested<A> addNewCatalogHealth();
    public SubscriptionStatusFluent.CatalogHealthNested<A> addNewCatalogHealthLike(SubscriptionCatalogHealth item);
    public SubscriptionStatusFluent.CatalogHealthNested<A> setNewCatalogHealthLike(int index,SubscriptionCatalogHealth item);
    public SubscriptionStatusFluent.CatalogHealthNested<A> editCatalogHealth(int index);
    public SubscriptionStatusFluent.CatalogHealthNested<A> editFirstCatalogHealth();
    public SubscriptionStatusFluent.CatalogHealthNested<A> editLastCatalogHealth();
    public SubscriptionStatusFluent.CatalogHealthNested<A> editMatchingCatalogHealth(io.fabric8.kubernetes.api.builder.Predicate<SubscriptionCatalogHealthBuilder> predicate);
    public A addToConditions(int index,SubscriptionCondition item);
    public A setToConditions(int index,SubscriptionCondition item);
    public A addToConditions(SubscriptionCondition... items);
    public A addAllToConditions(Collection<SubscriptionCondition> items);
    public A removeFromConditions(SubscriptionCondition... items);
    public A removeAllFromConditions(Collection<SubscriptionCondition> items);
    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<SubscriptionConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<SubscriptionCondition> getConditions();
    public List<SubscriptionCondition> buildConditions();
    public SubscriptionCondition buildCondition(int index);
    public SubscriptionCondition buildFirstCondition();
    public SubscriptionCondition buildLastCondition();
    public SubscriptionCondition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<SubscriptionConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<SubscriptionConditionBuilder> predicate);
    public A withConditions(List<SubscriptionCondition> conditions);
    public A withConditions(SubscriptionCondition... conditions);
    public Boolean hasConditions();
    public SubscriptionStatusFluent.ConditionsNested<A> addNewCondition();
    public SubscriptionStatusFluent.ConditionsNested<A> addNewConditionLike(SubscriptionCondition item);
    public SubscriptionStatusFluent.ConditionsNested<A> setNewConditionLike(int index,SubscriptionCondition item);
    public SubscriptionStatusFluent.ConditionsNested<A> editCondition(int index);
    public SubscriptionStatusFluent.ConditionsNested<A> editFirstCondition();
    public SubscriptionStatusFluent.ConditionsNested<A> editLastCondition();
    public SubscriptionStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<SubscriptionConditionBuilder> predicate);
    public String getCurrentCSV();
    public A withCurrentCSV(String currentCSV);
    public Boolean hasCurrentCSV();
    public A withNewCurrentCSV(String arg1);
    public A withNewCurrentCSV(StringBuilder arg1);
    public A withNewCurrentCSV(StringBuffer arg1);
    public Integer getInstallPlanGeneration();
    public A withInstallPlanGeneration(Integer installPlanGeneration);
    public Boolean hasInstallPlanGeneration();
    
/**
 * This method has been deprecated, please use method buildInstallPlanRef instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getInstallPlanRef();
    public ObjectReference buildInstallPlanRef();
    public A withInstallPlanRef(ObjectReference installPlanRef);
    public Boolean hasInstallPlanRef();
    public SubscriptionStatusFluent.InstallPlanRefNested<A> withNewInstallPlanRef();
    public SubscriptionStatusFluent.InstallPlanRefNested<A> withNewInstallPlanRefLike(ObjectReference item);
    public SubscriptionStatusFluent.InstallPlanRefNested<A> editInstallPlanRef();
    public SubscriptionStatusFluent.InstallPlanRefNested<A> editOrNewInstallPlanRef();
    public SubscriptionStatusFluent.InstallPlanRefNested<A> editOrNewInstallPlanRefLike(ObjectReference item);
    public String getInstalledCSV();
    public A withInstalledCSV(String installedCSV);
    public Boolean hasInstalledCSV();
    public A withNewInstalledCSV(String arg1);
    public A withNewInstalledCSV(StringBuilder arg1);
    public A withNewInstalledCSV(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildInstallplan instead.
 * @return The buildable object.
 */
@Deprecated public InstallPlanReference getInstallplan();
    public InstallPlanReference buildInstallplan();
    public A withInstallplan(InstallPlanReference installplan);
    public Boolean hasInstallplan();
    public A withNewInstallplan(String apiVersion,String kind,String name,String uuid);
    public SubscriptionStatusFluent.InstallplanNested<A> withNewInstallplan();
    public SubscriptionStatusFluent.InstallplanNested<A> withNewInstallplanLike(InstallPlanReference item);
    public SubscriptionStatusFluent.InstallplanNested<A> editInstallplan();
    public SubscriptionStatusFluent.InstallplanNested<A> editOrNewInstallplan();
    public SubscriptionStatusFluent.InstallplanNested<A> editOrNewInstallplanLike(InstallPlanReference item);
    public String getLastUpdated();
    public A withLastUpdated(String lastUpdated);
    public Boolean hasLastUpdated();
    public A withNewLastUpdated(String arg1);
    public A withNewLastUpdated(StringBuilder arg1);
    public A withNewLastUpdated(StringBuffer arg1);
    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public A withNewReason(String arg1);
    public A withNewReason(StringBuilder arg1);
    public A withNewReason(StringBuffer arg1);
    public String getState();
    public A withState(String state);
    public Boolean hasState();
    public A withNewState(String arg1);
    public A withNewState(StringBuilder arg1);
    public A withNewState(StringBuffer arg1);
    public interface CatalogHealthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubscriptionCatalogHealthFluent<SubscriptionStatusFluent.CatalogHealthNested<N>> {

        public N and();
        public N endCatalogHealth();    }


    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubscriptionConditionFluent<SubscriptionStatusFluent.ConditionsNested<N>> {

        public N and();
        public N endCondition();    }


    public interface InstallPlanRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<SubscriptionStatusFluent.InstallPlanRefNested<N>> {

        public N and();
        public N endInstallPlanRef();    }


    public interface InstallplanNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InstallPlanReferenceFluent<SubscriptionStatusFluent.InstallplanNested<N>> {

        public N and();
        public N endInstallplan();    }


}

==> openshift-model-operatorhub-5.0.1-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface SubscriptionStatusFluent<A extends SubscriptionStatusFluent<A>> extends Fluent<A> {


    public A addToCatalogHealth(int index,SubscriptionCatalogHealth item);
    public A setToCatalogHealth(int index,SubscriptionCatalogHealth item);
    public A addToCatalogHealth(SubscriptionCatalogHealth... items);
    public A addAllToCatalogHealth(Collection<SubscriptionCatalogHealth> items);
    public A removeFromCatalogHealth(SubscriptionCatalogHealth... items);
    public A removeAllFromCatalogHealth(Collection<SubscriptionCatalogHealth> items);
    public A removeMatchingFromCatalogHealth(Predicate<SubscriptionCatalogHealthBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildCatalogHealth instead.
 * @return The buildable object.
 */
@Deprecated public List<SubscriptionCatalogHealth> getCatalogHealth();
    public List<SubscriptionCatalogHealth> buildCatalogHealth();
    public SubscriptionCatalogHealth buildCatalogHealth(int index);
    public SubscriptionCatalogHealth buildFirstCatalogHealth();
    public SubscriptionCatalogHealth buildLastCatalogHealth();
    public SubscriptionCatalogHealth buildMatchingCatalogHealth(Predicate<SubscriptionCatalogHealthBuilder> predicate);
    public Boolean hasMatchingCatalogHealth(Predicate<SubscriptionCatalogHealthBuilder> predicate);
    public A withCatalogHealth(List<SubscriptionCatalogHealth> catalogHealth);
    public A withCatalogHealth(SubscriptionCatalogHealth... catalogHealth);
    public Boolean hasCatalogHealth();
    public SubscriptionStatusFluent.CatalogHealthNested<A> addNewCatalogHealth();
    public SubscriptionStatusFluent.CatalogHealthNested<A> addNewCatalogHealthLike(SubscriptionCatalogHealth item);
    public SubscriptionStatusFluent.CatalogHealthNested<A> setNewCatalogHealthLike(int index,SubscriptionCatalogHealth item);
    public SubscriptionStatusFluent.CatalogHealthNested<A> editCatalogHealth(int index);
    public SubscriptionStatusFluent.CatalogHealthNested<A> editFirstCatalogHealth();
    public SubscriptionStatusFluent.CatalogHealthNested<A> editLastCatalogHealth();
    public SubscriptionStatusFluent.CatalogHealthNested<A> editMatchingCatalogHealth(Predicate<SubscriptionCatalogHealthBuilder> predicate);
    public A addToConditions(int index,SubscriptionCondition item);
    public A setToConditions(int index,SubscriptionCondition item);
    public A addToConditions(SubscriptionCondition... items);
    public A addAllToConditions(Collection<SubscriptionCondition> items);
    public A removeFromConditions(SubscriptionCondition... items);
    public A removeAllFromConditions(Collection<SubscriptionCondition> items);
    public A removeMatchingFromConditions(Predicate<SubscriptionConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<SubscriptionCondition> getConditions();
    public List<SubscriptionCondition> buildConditions();
    public SubscriptionCondition buildCondition(int index);
    public SubscriptionCondition buildFirstCondition();
    public SubscriptionCondition buildLastCondition();
    public SubscriptionCondition buildMatchingCondition(Predicate<SubscriptionConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<SubscriptionConditionBuilder> predicate);
    public A withConditions(List<SubscriptionCondition> conditions);
    public A withConditions(SubscriptionCondition... conditions);
    public Boolean hasConditions();
    public SubscriptionStatusFluent.ConditionsNested<A> addNewCondition();
    public SubscriptionStatusFluent.ConditionsNested<A> addNewConditionLike(SubscriptionCondition item);
    public SubscriptionStatusFluent.ConditionsNested<A> setNewConditionLike(int index,SubscriptionCondition item);
    public SubscriptionStatusFluent.ConditionsNested<A> editCondition(int index);
    public SubscriptionStatusFluent.ConditionsNested<A> editFirstCondition();
    public SubscriptionStatusFluent.ConditionsNested<A> editLastCondition();
    public SubscriptionStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<SubscriptionConditionBuilder> predicate);
    public String getCurrentCSV();
    public A withCurrentCSV(String currentCSV);
    public Boolean hasCurrentCSV();
    public A withNewCurrentCSV(String arg1);
    public A withNewCurrentCSV(StringBuilder arg1);
    public A withNewCurrentCSV(StringBuffer arg1);
    public Integer getInstallPlanGeneration();
    public A withInstallPlanGeneration(Integer installPlanGeneration);
    public Boolean hasInstallPlanGeneration();
    
/**
 * This method has been deprecated, please use method buildInstallPlanRef instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getInstallPlanRef();
    public ObjectReference buildInstallPlanRef();
    public A withInstallPlanRef(ObjectReference installPlanRef);
    public Boolean hasInstallPlanRef();
    public SubscriptionStatusFluent.InstallPlanRefNested<A> withNewInstallPlanRef();
    public SubscriptionStatusFluent.InstallPlanRefNested<A> withNewInstallPlanRefLike(ObjectReference item);
    public SubscriptionStatusFluent.InstallPlanRefNested<A> editInstallPlanRef();
    public SubscriptionStatusFluent.InstallPlanRefNested<A> editOrNewInstallPlanRef();
    public SubscriptionStatusFluent.InstallPlanRefNested<A> editOrNewInstallPlanRefLike(ObjectReference item);
    public String getInstalledCSV();
    public A withInstalledCSV(String installedCSV);
    public Boolean hasInstalledCSV();
    public A withNewInstalledCSV(String arg1);
    public A withNewInstalledCSV(StringBuilder arg1);
    public A withNewInstalledCSV(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildInstallplan instead.
 * @return The buildable object.
 */
@Deprecated public InstallPlanReference getInstallplan();
    public InstallPlanReference buildInstallplan();
    public A withInstallplan(InstallPlanReference installplan);
    public Boolean hasInstallplan();
    public A withNewInstallplan(String apiVersion,String kind,String name,String uuid);
    public SubscriptionStatusFluent.InstallplanNested<A> withNewInstallplan();
    public SubscriptionStatusFluent.InstallplanNested<A> withNewInstallplanLike(InstallPlanReference item);
    public SubscriptionStatusFluent.InstallplanNested<A> editInstallplan();
    public SubscriptionStatusFluent.InstallplanNested<A> editOrNewInstallplan();
    public SubscriptionStatusFluent.InstallplanNested<A> editOrNewInstallplanLike(InstallPlanReference item);
    public String getLastUpdated();
    public A withLastUpdated(String lastUpdated);
    public Boolean hasLastUpdated();
    public A withNewLastUpdated(String arg1);
    public A withNewLastUpdated(StringBuilder arg1);
    public A withNewLastUpdated(StringBuffer arg1);
    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public A withNewReason(String arg1);
    public A withNewReason(StringBuilder arg1);
    public A withNewReason(StringBuffer arg1);
    public String getState();
    public A withState(String state);
    public Boolean hasState();
    public A withNewState(String arg1);
    public A withNewState(StringBuilder arg1);
    public A withNewState(StringBuffer arg1);
    public interface CatalogHealthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubscriptionCatalogHealthFluent<SubscriptionStatusFluent.CatalogHealthNested<N>> {

            public N and();
            public N endCatalogHealth();    }


    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubscriptionConditionFluent<SubscriptionStatusFluent.ConditionsNested<N>> {

            public N and();
            public N endCondition();    }


    public interface InstallPlanRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<SubscriptionStatusFluent.InstallPlanRefNested<N>> {

            public N and();
            public N endInstallPlanRef();    }


    public interface InstallplanNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InstallPlanReferenceFluent<SubscriptionStatusFluent.InstallplanNested<N>> {

            public N and();
            public N endInstallplan();    }


}
